@@ -18,11 +18,11 @@ package v1
 
 import (
 	"context"
-
-	"github.com/google/uuid"
+	"strconv"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
+	"k8s.io/apimachinery/pkg/util/sets"
 	"knative.dev/pkg/apis"
 	"knative.dev/pkg/kmeta"
 	"knative.dev/pkg/ptr"
@@ -31,6 +31,11 @@ import (
 
 // SetDefaults implements apis.Defaultable
 func (r *Revision) SetDefaults(ctx context.Context) {
+	// SetDefaults may update revision spec which is immutable.
+	// See: https://github.com/knative/serving/issues/8128 for details.
+	if apis.IsInUpdate(ctx) {
+		return
+	}
 	r.Spec.SetDefaults(apis.WithinSpec(ctx))
 }
 
@@ -43,23 +48,43 @@ func (rts *RevisionTemplateSpec) SetDefaults(ctx context.Context) {
 func (rs *RevisionSpec) SetDefaults(ctx context.Context) {
 	cfg := config.FromContextOrDefaults(ctx)
 
-	// Default TimeoutSeconds based on our configmap
+	// Default TimeoutSeconds based on our configmap.
 	if rs.TimeoutSeconds == nil || *rs.TimeoutSeconds == 0 {
 		rs.TimeoutSeconds = ptr.Int64(cfg.Defaults.RevisionTimeoutSeconds)
 	}
 
-	// Default ContainerConcurrency based on our configmap
+	// Default ContainerConcurrency based on our configmap.
 	if rs.ContainerConcurrency == nil {
 		rs.ContainerConcurrency = ptr.Int64(cfg.Defaults.ContainerConcurrency)
 	}
 
+	// Avoid clashes with user-supplied names when generating defaults.
+	userContainerNames := make(sets.String, len(rs.PodSpec.Containers))
+	for idx := range rs.PodSpec.Containers {
+		userContainerNames.Insert(rs.PodSpec.Containers[idx].Name)
+	}
+
+	// Default container name based on UserContainerName value from configmap.
+	// In multi-container mode, add a numeric suffix, avoiding clashes with user-supplied names.
+	nextSuffix := 0
+	defaultContainerName := cfg.Defaults.UserContainerName(ctx)
 	for idx := range rs.PodSpec.Containers {
 		if rs.PodSpec.Containers[idx].Name == "" {
+			name := defaultContainerName
+
 			if len(rs.PodSpec.Containers) > 1 {
-				rs.PodSpec.Containers[idx].Name = kmeta.ChildName(cfg.Defaults.UserContainerName(ctx), "-"+uuid.New().String())
-			} else {
-				rs.PodSpec.Containers[idx].Name = cfg.Defaults.UserContainerName(ctx)
+				for {
+					name = kmeta.ChildName(defaultContainerName, "-"+strconv.Itoa(nextSuffix))
+					nextSuffix++
+
+					// Continue until we get a name that doesn't clash with a user-supplied name.
+					if !userContainerNames.Has(name) {
+						break
+					}
+				}
 			}
+
+			rs.PodSpec.Containers[idx].Name = name
 		}
 
 		rs.applyDefault(&rs.PodSpec.Containers[idx], cfg)
